@@ -46,8 +46,8 @@
 #include <KToolBar>
 #include <KXMLGUIFactory>
 
-#include <Phonon/BackendCapabilities>
-#include <Phonon/VideoWidget>
+#include <phonon/BackendCapabilities>
+#include <phonon/VideoWidget>
 
 #include <Solid/Device>
 #include <Solid/OpticalDisc>
@@ -956,3 +956,5 @@ void MainWindow::contextMenuEvent(QContextMenuEvent *event)
     menu.exec(event->globalPos());
 }
 } // namespace Dragon
+
+#include "moc_mainWindow.cpp"
